# saturn-bot-python

Python SDK to write plugins for [saturn-bot](https://github.com/wndhydrnt/saturn-bot).

Take a look at the [examples](./examples) and the [documentation](https://saturn-bot.readthedocs.io/en/latest/task/plugins/) to get started.
